aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/webbrowser.c
diff options
context:
space:
mode:
authorguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2006-05-22 07:29:40 +0000
committerguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2006-05-22 07:29:40 +0000
commitd33e03cac01be1f8b358fd6fd25a9c1221a0910f (patch)
treebb7476c5cd4845fce70a943d87cab8ddb12fe41d /gtk/webbrowser.c
parente4adc6ff405a70498984521cb05d512b48611b45 (diff)
Get rid of a bunch of "Ethereal"s and "ethereal"s in comments, GUI
strings, and function names. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@18205 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'gtk/webbrowser.c')
-rw-r--r--gtk/webbrowser.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/gtk/webbrowser.c b/gtk/webbrowser.c
index e0be890eb3..debd00bff1 100644
--- a/gtk/webbrowser.c
+++ b/gtk/webbrowser.c
@@ -21,11 +21,11 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* Ethereal - this file is copied from "The GIMP" V2.0.2
* You will find the original file in the gimp distribution zip under:
* \plug-ins\common\webbrowser.c
*
- * It was modified to suit the Ethereal environment (#if 0)!
+ * It was modified to suit the Wireshark environment (#if 0)!
*/
#include "config.h"
@@ -43,8 +43,8 @@
/*
* For GNOME 2.x, we might be able to use "gnome_url_show()" (when we offer
* the ability to build a GNOMEified Ethereal as well as a GTK+-only
* Ethereal).
*/
#if defined(G_OS_WIN32)
@@ -197,7 +197,7 @@ browser_open_url (const gchar *url)
XXX - has to be improved */
simple_dialog(ESD_TYPE_INFO, ESD_BTN_OK,
PRIMARY_TEXT_START "Web browser access not implemented." PRIMARY_TEXT_END
- "\n\nThis Ethereal version (using the GLib 1.x toolkit) can't access web browsers. "
+ "\n\nThis Wireshark version (using the GLib 1.x toolkit) can't access web browsers. "
"\n\nYou may try to open the following URL in your web browser: \n\n"
"%s",
url);
@@ -21,11 +21,11 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* Ethereal - this file is copied from "The GIMP" V2.0.2
+/* Wireshark - this file is copied from "The GIMP" V2.0.2
* You will find the original file in the gimp distribution zip under:
* \plug-ins\common\webbrowser.c
@@ -43,8 +43,8 @@
/*
* For GNOME 2.x, we might be able to use "gnome_url_show()" (when we offer
- * the ability to build a GNOMEified Ethereal as well as a GTK+-only
- * Ethereal).
+ * the ability to build a GNOMEified Wireshark as well as a GTK+-only
+ * Wireshark).
*/
#if defined(G_OS_WIN32)